import pandas as pd
import numpy as np
import os


def create_column_format_for_tex(df: pd.DataFrame) -> str:
    """
    Creates column format for latex table based on the shape of a given DataFrame.

    Calculates number of columns and uses 'c' as column position. First element is set to 'l', last to 'r'
    """
    column_format = np.repeat('c', df.shape[1] + 1)
    column_format[0] = 'l'
    column_format[-1] = 'r'
    column_format = ''.join(column_format.tolist())
    return column_format


def save_to_tex(path, filename, column_format, df, na_rep='---'):
    df.to_latex(os.path.join(path, filename), na_rep=na_rep, column_format=column_format)


def save_to_md(path, filename, df, mode="w", encoding='utf-8', tablefmt="github"):
    df.to_markdown(open(os.path.join(path, filename), mode=mode, encoding=encoding), tablefmt=tablefmt)
